@@ -651,7 +651,11 @@ static const struct drm_ioctl_desc nv_drm_ioctls[] = {
 
 static struct drm_driver nv_drm_driver = {
 
-    .driver_features        = DRIVER_GEM | DRIVER_PRIME | DRIVER_RENDER,
+    .driver_features        =
+#if defined(NV_DRM_DRIVER_PRIME_FLAG_PRESENT)
+                               DRIVER_PRIME |
+#endif
+                               DRIVER_GEM  | DRIVER_RENDER,
 
     .gem_free_object        = nv_drm_gem_free,
 
